import filehydra.filehydra_core as fh


fh1=fh.FileHydra()

fh1.move_file("", "txt",  "C:\\Users\\EUROCOM\\Documents\\Git\\DovaX\\forloop-projects\\idealista\\high_level_queue", "C:\\Users\\EUROCOM\\Documents\\Git\\DovaX\\forloop-projects\\idealista\\high_level_queue\\processed", 0)